package com.persagy.dmp.auth.service.impl;

import cn.hutool.core.util.StrUtil;
import com.persagy.dmp.auth.service.AuthService;
import com.persagy.dmp.common.constant.CommonConstant;
import com.persagy.dmp.common.context.AppContext;
import com.persagy.dmp.common.helper.SpringHelper;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 登录认证处理抽象类
 * @author Charlie Yu
 * @date 2021-11-02
 */
public abstract class AbstractAuthServiceImpl implements AuthService {

    @Override
    public boolean validateLogin(HttpServletRequest request, HttpServletResponse response) {
        // 登录认证通常在网关完成，无网关服务在此完成
        return true;
    }

    @Override
    public void loginSuccess(HttpServletRequest request, HttpServletResponse response) {

    }

    @Override
    public void loginFailure(HttpServletRequest request, HttpServletResponse response) {

    }

    @Override
    public void release(HttpServletRequest request, HttpServletResponse response) {
        // 释放上下文缓存
        AppContext.unload();
    }

    /**
     * 从请求中装载上下文
     * @param request
     */
    protected void loadContextByRequest(HttpServletRequest request) {
        AppContext context = AppContext.getContext();
        if (SpringHelper.getBoolean(AppContext.PERSAGY_COMMON_AUTH_CONTEXT_SOURCE,true)){
            context.setGroupCode(request.getParameter(AppContext.GROUP_CODE));
            context.setProjectId(request.getParameter(AppContext.PROJECT_ID));
            context.setAppId(request.getParameter(AppContext.APP_ID));
            context.setAccountId(request.getParameter(AppContext.USER_ID));
        }else {
            context.setGroupCode(request.getHeader(AppContext.GROUP_CODE));
            context.setProjectId(request.getHeader(AppContext.PROJECT_ID));
            context.setAppId(request.getHeader(AppContext.APP_ID));
            context.setAccountId(request.getHeader(AppContext.USER_ID));
            // 无集团编码时，默认为配置的集团编码
            String groupCode = request.getHeader(AppContext.GROUP_CODE);
            if(StrUtil.isBlank(groupCode)) {
                context.setGroupCode(SpringHelper.getString("middleware.group.code"));
            }
            // 无项目id时,尝试从请求URL中获取
            if (StrUtil.isBlank(request.getHeader(AppContext.PROJECT_ID))
                    && StrUtil.isNotBlank(request.getParameter(CommonConstant.QUERY_PROJECTID))){
                context.setProjectId(request.getParameter(CommonConstant.QUERY_PROJECTID));
            }
        }
        // 无用户时，默认为默认系统用户
        if(StrUtil.isBlank(context.getAccountId())) {
            context.setAccountId(CommonConstant.DEFAULT_ID);
        }
    }
}
